summaryrefslogtreecommitdiff
path: root/compiler/GHC/Hs/Utils.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Hs/Utils.hs')
-rw-r--r--compiler/GHC/Hs/Utils.hs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/GHC/Hs/Utils.hs b/compiler/GHC/Hs/Utils.hs
index 6301927b26..cbb21b1ad0 100644
--- a/compiler/GHC/Hs/Utils.hs
+++ b/compiler/GHC/Hs/Utils.hs
@@ -110,7 +110,7 @@ import GHC.Hs.Decls
import GHC.Hs.Binds
import GHC.Hs.Expr
import GHC.Hs.Pat
-import GHC.Hs.Types
+import GHC.Hs.Type
import GHC.Hs.Lit
import GHC.Hs.Extension
@@ -745,7 +745,7 @@ typeToLHsType ty
argf_to_spec :: ArgFlag -> Specificity
argf_to_spec Required = SpecifiedSpec
- -- see Note [Specificity in HsForAllTy] in GHC.Hs.Types
+ -- see Note [Specificity in HsForAllTy] in GHC.Hs.Type
argf_to_spec (Invisible s) = s
go_tv :: TyVarBinder -> LHsTyVarBndr Specificity GhcPs